@@ -1,4 +1,4 @@
-from atlassian import Jira, Confluence, Stash, Portfolio, Bamboo
+from atlassian import Jira, Confluence, Bitbucket, Portfolio, Bamboo, Crowd
 import os
 
 
@@ -7,6 +7,10 @@ JIRA_URL = os.environ.get('BAMBOO_URL', 'http://localhost:8080')
 CONFLUENCE_URL = os.environ.get('BAMBOO_URL', 'http://localhost:8090')
 STASH_URL = os.environ.get('BAMBOO_URL', 'http://localhost:7990')
 
+CROWD_URL = os.environ.get('CROWD_URL', 'http://localhost:8095/crowd')
+CROWD_APPLICATION = os.environ.get('CROWD_APPLICATION', 'bamboo')
+CROWD_APPLICATION_PASSWORD = os.environ.get('CROWD_APPLICATION_PASSWORD', 'admin')
+
 ATLASSIAN_USER = os.environ.get('ATLASSIAN_USER', 'admin')
 ATLASSIAN_PASSWORD = os.environ.get('ATLASSIAN_PASSWORD', 'admin')
 
@@ -27,8 +31,8 @@ class TestBasic(object):
             password=ATLASSIAN_PASSWORD
         )
 
-    def test_init_stash(self):
-        stash = Stash(
+    def test_init_bitbucket(self):
+        bitbucket = Bitbucket(
             url=STASH_URL,
             username=ATLASSIAN_USER,
             password=ATLASSIAN_PASSWORD
@@ -41,4 +45,8 @@ class TestBasic(object):
             password=ATLASSIAN_PASSWORD
         )
 
-
+    def test_init_crowd(self):
+        crowd = Crowd(
+            url=CROWD_URL,
+            username=CROWD_APPLICATION,
+            password=CROWD_APPLICATION_PASSWORD)
